@@ -19,10 +19,6 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
 #ifdef HAVE_MEMORY_H
 #include <memory.h>
 #endif
