@@ -19,10 +19,6 @@
  * Boston, MA 02110-1301  USA
  */
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
 #include "twp-provider.h"
 
 #ifdef ENABLE_X11
