@@ -17,13 +17,10 @@
  * Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
+#include "thunar/thunar-details-view.h"
 
 #include "thunar/thunar-action-manager.h"
 #include "thunar/thunar-column-editor.h"
-#include "thunar/thunar-details-view.h"
 #include "thunar/thunar-gtk-extensions.h"
 #include "thunar/thunar-preferences.h"
 #include "thunar/thunar-private.h"
@@ -900,7 +897,7 @@ thunar_details_view_button_press_event (GtkTreeView       *tree_view,
               gtk_tree_selection_unselect_all (selection);
               if (gtk_tree_model_get_iter (model, &iter, path))
                 {
-                  file = thunar_standard_view_model_get_file (THUNAR_STANDARD_VIEW_MODEL (model), &iter);
+                  file = thunar_tree_view_model_get_file (THUNAR_TREE_VIEW_MODEL (model), &iter);
                   if (file != NULL)
                     {
                       row_selected = TRUE;
@@ -946,7 +943,7 @@ thunar_details_view_button_press_event (GtkTreeView       *tree_view,
                   gtk_tree_selection_unselect_all (selection);
                   if (gtk_tree_model_get_iter (model, &iter, path))
                     {
-                      file = thunar_standard_view_model_get_file (THUNAR_STANDARD_VIEW_MODEL (model), &iter);
+                      file = thunar_tree_view_model_get_file (THUNAR_TREE_VIEW_MODEL (model), &iter);
                       if (file != NULL)
                         {
                           g_object_unref (file);
@@ -974,7 +971,7 @@ thunar_details_view_button_press_event (GtkTreeView       *tree_view,
           gtk_tree_selection_unselect_all (selection);
           if (gtk_tree_model_get_iter (model, &iter, mc_path))
             {
-              file = thunar_standard_view_model_get_file (THUNAR_STANDARD_VIEW_MODEL (model), &iter);
+              file = thunar_tree_view_model_get_file (THUNAR_TREE_VIEW_MODEL (model), &iter);
               if (file != NULL)
                 {
                   g_object_unref (file);
@@ -1016,7 +1013,7 @@ tree_view_set_cursor_if_file_not_null (GtkTreeView  *tree_view,
   if (!gtk_tree_model_get_iter (model, &iter, path))
     return FALSE;
 
-  file = thunar_standard_view_model_get_file (THUNAR_STANDARD_VIEW_MODEL (model), &iter);
+  file = thunar_tree_view_model_get_file (THUNAR_TREE_VIEW_MODEL (model), &iter);
 
   if (file == NULL)
     return FALSE;
