@@ -17,10 +17,6 @@
  * Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
-
 #include "thunar/thunar-device-monitor.h"
 #include "thunar/thunar-device.h"
 #include "thunar/thunar-file.h"
