@@ -18,10 +18,6 @@
  * Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
-
 #include "thunar/thunar-enum-types.h"
 
 #include <libxfce4util/libxfce4util.h>
@@ -946,3 +942,50 @@ thunar_execute_shell_script_get_type (void)
 
   return type;
 }
+
+GType
+thunar_file_drag_mode_get_type (void)
+{
+  static GType type = G_TYPE_INVALID;
+
+  if (G_UNLIKELY (type == G_TYPE_INVALID))
+    {
+      /* clang-format off */
+      static const GEnumValue values[] =
+      {
+        { THUNAR_FILE_DRAG_MODE_DISABLED,         "THUNAR_FILE_DRAG_MODE_DISABLED",         "dnd disabled for files" },
+        { THUNAR_FILE_DRAG_MODE_MENU_CONDITIONAL, "THUNAR_FILE_DRAG_MODE_MENU_CONDITIONAL", "dnd menu only on file right clicks" },
+        { THUNAR_FILE_DRAG_MODE_MENU_ALWAYS,      "THUNAR_FILE_DRAG_MODE_MENU_ALWAYS",      "dnd menu for files always shown" },
+        { 0,                                       NULL,                                    NULL }
+      };
+      /* clang-format on */
+
+      type = g_enum_register_static ("ThunarFileDragMode", values);
+    }
+
+  return type;
+}
+
+GType
+thunar_terminal_sync_mode_get_type (void)
+{
+  static GType type = G_TYPE_INVALID;
+
+  if (G_UNLIKELY (type == G_TYPE_INVALID))
+    {
+      /* clang-format off */
+      static const GEnumValue values[] =
+      {
+        { THUNAR_TERMINAL_SYNC_NONE,       "THUNAR_TERMINAL_SYNC_NONE",       N_("Disabled") },
+        { THUNAR_TERMINAL_SYNC_FM_TO_TERM, "THUNAR_TERMINAL_SYNC_FM_TO_TERM", N_("File Manager → Terminal") },
+        { THUNAR_TERMINAL_SYNC_TERM_TO_FM, "THUNAR_TERMINAL_SYNC_TERM_TO_FM", N_("Terminal → File Manager") },
+        { THUNAR_TERMINAL_SYNC_BOTH,       "THUNAR_TERMINAL_SYNC_BOTH",       N_("Both Ways") },
+        { 0,                               NULL,                                NULL },
+      };
+      /* clang-format on */
+
+      type = g_enum_register_static (I_ ("ThunarTerminalSyncMode"), values);
+    }
+
+  return type;
+}
