@@ -173,6 +173,8 @@ typedef enum
   THUNAR_ICON_SIZE_1024 = 1024,
 } ThunarIconSize;
 #define THUNAR_ICON_SIZE_DIALOG 48
+#define THUNAR_TERMINAL_MIN_MAIN_VIEW_HEIGHT 200
+#define THUNAR_TERMINAL_MIN_TERMINAL_HEIGHT 50
 
 GType
 thunar_icon_size_get_type (void) G_GNUC_CONST;
@@ -639,6 +641,49 @@ typedef enum
 GType
 thunar_execute_shell_script_get_type (void) G_GNUC_CONST;
 
+/**
+ * ThunarFileDragMode
+ *
+ * Controls what is done for drag and drop actions on files
+ **/
+#define THUNAR_TYPE_FILE_DRAG_MODE (thunar_file_drag_mode_get_type ())
+
+/**
+ * ThunarFileDragMode:
+ * @THUNAR_FILE_DRAG_MODE_DISABLED,          : dnd is disabled for files
+ * @THUNAR_FILE_DRAG_MODE_MENU_CONDITIONAL,  : only use DND menu for right click DND
+ * @THUNAR_FILE_DRAG_MODE_MENU_ALWAYS,       : always show the DND menu when files are dragged
+ **/
+typedef enum
+{
+  THUNAR_FILE_DRAG_MODE_DISABLED,
+  THUNAR_FILE_DRAG_MODE_MENU_CONDITIONAL,
+  THUNAR_FILE_DRAG_MODE_MENU_ALWAYS,
+} ThunarFileDragMode;
+
+GType
+thunar_file_drag_mode_get_type (void) G_GNUC_CONST;
+#define THUNAR_TYPE_TERMINAL_SYNC_MODE (thunar_terminal_sync_mode_get_type ())
+
+/**
+ * ThunarTerminalSyncMode:
+ * @THUNAR_TERMINAL_SYNC_NONE: No synchronization.
+ * @THUNAR_TERMINAL_SYNC_FM_TO_TERM: File manager changes directory in terminal.
+ * @THUNAR_TERMINAL_SYNC_TERM_TO_FM: Terminal changes directory in file manager.
+ * @THUNAR_TERMINAL_SYNC_BOTH: Bidirectional synchronization.
+ **/
+typedef enum
+{
+  THUNAR_TERMINAL_SYNC_NONE,
+  THUNAR_TERMINAL_SYNC_FM_TO_TERM,
+  THUNAR_TERMINAL_SYNC_TERM_TO_FM,
+  THUNAR_TERMINAL_SYNC_BOTH,
+} ThunarTerminalSyncMode;
+
+GType
+thunar_terminal_sync_mode_get_type (void) G_GNUC_CONST;
+
+
 G_END_DECLS;
 
 #endif /* !__THUNAR_ENUM_TYPES_H__ */
