@@ -18,10 +18,6 @@
  * Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
-
 #ifdef HAVE_ERRNO_H
 #include <errno.h>
 #endif
@@ -128,6 +124,9 @@ enum
   PROP_MISC_IMAGE_PREVIEW_FULL,
   PROP_SHORTCUTS_ICON_EMBLEMS,
   PROP_SHORTCUTS_ICON_SIZE,
+  PROP_SHORTCUTS_DISK_SPACE_USAGE_BAR,
+  PROP_SHORTCUTS_DISK_SPACE_USAGE_WARNING_PERCENT,
+  PROP_SHORTCUTS_DISK_SPACE_USAGE_ERROR_PERCENT,
   PROP_TREE_ICON_EMBLEMS,
   PROP_TREE_ICON_SIZE,
   PROP_TREE_LINES,
@@ -146,6 +145,17 @@ enum
   PROP_MISC_SYMBOLIC_ICONS_IN_SIDEPANE,
   PROP_MISC_CTRL_SCROLL_WHEEL_TO_ZOOM,
   PROP_MISC_USE_CSD,
+  PROP_SMART_SORT,
+  PROP_MISC_FILE_DRAG_MODE,
+#ifdef HAVE_VTE
+  PROP_TERMINAL_HEIGHT,
+  PROP_TERMINAL_VISIBLE,
+  PROP_TERMINAL_COLOR_SCHEME,
+  PROP_TERMINAL_TERMINAL_SYNC_MODE,
+  PROP_TERMINAL_SSH_AUTO_CONNECT,
+  PROP_TERMINAL_SSH_AUTO_DISCONNECT,
+  PROP_TERMINAL_FONT_SIZE,
+#endif
   N_PROPERTIES
 };
 
@@ -255,6 +265,27 @@ thunar_preferences_class_init (ThunarPreferencesClass *klass)
                       G_TYPE_STRV,
                       G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
 
+  /**
+   * ThunarPreferences:smart-sort:
+   *
+   * %TRUE to use smart sorting to sort files by name.
+   *
+   * If enabled, filenames are split into collatable substrings and e.g. numbers are compared separately,
+   * in a numeric way instead of comparing them digit-by-digit.
+   * 
+   * Sort order example with smart sorting enabled:
+   * - file1 file5 file10
+   *
+   * Sort order example with smart sorting disabled (plain ASCII sorting):
+   * - file1 file10 file5
+   **/
+  preferences_props[PROP_SMART_SORT] =
+  g_param_spec_boolean ("smart-sort",
+                        "SortingSmartFilenames",
+                        NULL,
+                        TRUE, /* Default: smart sorting enabled */
+                        G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
+
   /**
    * ThunarPreferences:last-restore-tabs:
    *
@@ -1185,6 +1216,44 @@ thunar_preferences_class_init (ThunarPreferencesClass *klass)
                      THUNAR_ICON_SIZE_24,
                      G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
 
+  /**
+   * ThunarPreferences:disk-space-usage-bar:
+   *
+   * Progressbar that displays disk space usage
+   **/
+  preferences_props[PROP_SHORTCUTS_DISK_SPACE_USAGE_BAR] =
+  g_param_spec_boolean ("shortcuts-disk-space-usage-bar",
+                        "ShortcutsDiskSpaceUsageBar",
+                        NULL,
+                        TRUE,
+                        G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
+
+  /**
+   * ThunarPreferences:disk-space-usage-bar:
+   *
+   * Threshold value
+   **/
+  preferences_props[PROP_SHORTCUTS_DISK_SPACE_USAGE_WARNING_PERCENT] =
+  g_param_spec_int ("shortcuts-disk-space-usage-warning-percent",
+                    "ShortcutsDiskSpaceUsageWarningPercent",
+                    NULL,
+                    0, 100,
+                    90,
+                    G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
+
+  /**
+   * ThunarPreferences:disk-space-usage-bar:
+   *
+   * Threshold value
+   **/
+  preferences_props[PROP_SHORTCUTS_DISK_SPACE_USAGE_ERROR_PERCENT] =
+  g_param_spec_int ("shortcuts-disk-space-usage-error-percent",
+                    "ShortcutsDiskSpaceUsageErrorPercent",
+                    NULL,
+                    0, 100,
+                    95,
+                    G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
+
   /**
    * ThunarPreferences:tree-icon-emblems:
    *
@@ -1416,6 +1485,110 @@ thunar_preferences_class_init (ThunarPreferencesClass *klass)
                         FALSE,
                         G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
 
+  /**
+   * ThunarPreferences:misc-file-drag-mode:
+   *
+   * Controls what is done for drag and drop actions on files
+   **/
+  preferences_props[PROP_MISC_FILE_DRAG_MODE] =
+  g_param_spec_enum ("misc-file-drag-mode",
+                     "misc-file-drag-mode",
+                     NULL,
+                     THUNAR_TYPE_FILE_DRAG_MODE,
+                     THUNAR_FILE_DRAG_MODE_MENU_ALWAYS,
+                     G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
+
+  /**              
+   * ThunarPreferences:terminal-height:
+   *
+   * Height of the terminal widget in pixels.
+   **/
+  preferences_props[PROP_TERMINAL_HEIGHT] =
+  g_param_spec_int ("terminal-height",
+                    "TerminalHeight",
+                    NULL,
+                    THUNAR_TERMINAL_MIN_TERMINAL_HEIGHT, /* min height */
+                    G_MAXINT,                            /* max height */
+                    200,                                 /* default height */
+                    G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
+
+  /**
+   * ThunarPreferences:terminal-visible:
+   *
+   * %TRUE to show the terminal widget by default.
+   **/
+  preferences_props[PROP_TERMINAL_VISIBLE] =
+  g_param_spec_boolean ("terminal-visible",
+                        "TerminalVisible",
+                        NULL,
+                        FALSE,
+                        G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
+
+  /**
+   * ThunarPreferences:terminal-color-scheme:
+   *
+   * Color scheme name for the terminal widget.
+   **/
+  preferences_props[PROP_TERMINAL_COLOR_SCHEME] =
+  g_param_spec_string ("terminal-color-scheme",
+                       "TerminalColorScheme",
+                       NULL,
+                       "system",
+                       G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
+
+  /**
+   * ThunarPreferences:terminal-sync-mode:
+   *
+   * Synchronization mode between terminal and file manager for both local and SSH sessions.
+   **/
+  preferences_props[PROP_TERMINAL_TERMINAL_SYNC_MODE] =
+  g_param_spec_enum ("terminal-sync-mode",
+                     "TerminalSyncMode",
+                     NULL,
+                     THUNAR_TYPE_TERMINAL_SYNC_MODE,
+                     THUNAR_TERMINAL_SYNC_BOTH,
+                     G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
+
+  /**
+   * ThunarPreferences:terminal-ssh-auto-connect:
+   *
+   * Automatically connect SSH when navigating to SFTP locations.
+   **/
+  preferences_props[PROP_TERMINAL_SSH_AUTO_CONNECT] =
+  g_param_spec_boolean ("terminal-ssh-auto-connect",
+                        "TerminalSshAutoConnect",
+                        NULL,
+                        FALSE,
+                        G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
+
+  /**
+   * ThunarPreferences:terminal-ssh-auto-disconnect:
+   *
+   * Automatically disconnect SSH when leaving folder.
+   **/
+  preferences_props[PROP_TERMINAL_SSH_AUTO_DISCONNECT] =
+  g_param_spec_boolean ("terminal-ssh-auto-disconnect",
+                        "TerminalSshAutoDisconnect",
+                        NULL,
+                        FALSE,
+                        G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
+
+#ifdef HAVE_VTE
+  /**
+   * ThunarPreferences:terminal-font-size:
+   *
+   * Font size for the terminal widget in points.
+   **/
+  preferences_props[PROP_TERMINAL_FONT_SIZE] =
+  g_param_spec_int ("terminal-font-size",
+                    "TerminalFontSize",
+                    NULL,
+                    6,  /* min font size */
+                    72, /* max font size */
+                    12, /* default font size */
+                    G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
+#endif
+
   /* install all properties */
   g_object_class_install_properties (gobject_class, N_PROPERTIES, preferences_props);
 }
