@@ -17,10 +17,6 @@
  * Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
-
 #include "thunar/thunar-private.h"
 #include "thunar/thunar-renamer-progress.h"
 #include "thunar/thunar-util.h"
