@@ -19,10 +19,6 @@
  * Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
-
 #ifdef HAVE_ERRNO_H
 #include <errno.h>
 #endif
@@ -181,6 +177,9 @@ thunar_shortcuts_model_file_changed (ThunarFile           *file,
 static void
 thunar_shortcuts_model_file_destroyed (ThunarFile           *file,
                                        ThunarShortcutsModel *model);
+
+static GFile *
+thunar_shortcut_get_file (ThunarShortcut *shortcut);
 static void
 thunar_shortcut_free (ThunarShortcut       *shortcut,
                       ThunarShortcutsModel *model);
@@ -239,6 +238,13 @@ struct _ThunarShortcut
   guint hidden : 1;
 };
 
+typedef struct
+{
+  ThunarShortcutsModel *model;
+  ThunarShortcut       *shortcut;
+  gboolean              update_visibility;
+} ThunarShortcutFileGetData;
+
 
 
 G_DEFINE_TYPE_WITH_CODE (ThunarShortcutsModel, thunar_shortcuts_model, G_TYPE_OBJECT,
@@ -536,6 +542,9 @@ thunar_shortcuts_model_get_column_type (GtkTreeModel *tree_model,
 
     case THUNAR_SHORTCUTS_MODEL_COLUMN_HIDDEN:
       return G_TYPE_BOOLEAN;
+
+    case THUNAR_SHORTCUTS_MODEL_COLUMN_DISK_SPACE_USAGE_PERCENT:
+      return G_TYPE_INT;
     }
 
   _thunar_assert_not_reached ();
@@ -605,6 +614,8 @@ thunar_shortcuts_model_get_value (GtkTreeModel *tree_model,
   gchar          *tooltip;
   guint32         trash_items;
   gchar          *parse_name;
+  guint64         fs_free;
+  guint64         fs_size;
 
   _thunar_return_if_fail (iter->stamp == THUNAR_SHORTCUTS_MODEL (tree_model)->stamp);
   _thunar_return_if_fail (THUNAR_IS_SHORTCUTS_MODEL (tree_model));
@@ -656,12 +667,7 @@ thunar_shortcuts_model_get_value (GtkTreeModel *tree_model,
             device_id = NULL;
 
           /* get device root directory */
-          if (shortcut->device != NULL)
-            file = thunar_device_get_root (shortcut->device);
-          else if (shortcut->file != NULL)
-            file = g_object_ref (thunar_file_get_file (shortcut->file));
-          else
-            file = NULL;
+          file = thunar_shortcut_get_file (shortcut);
 
           if (file != NULL)
             {
@@ -816,6 +822,24 @@ thunar_shortcuts_model_get_value (GtkTreeModel *tree_model,
       g_value_set_boolean (value, FALSE);
       break;
 
+    case THUNAR_SHORTCUTS_MODEL_COLUMN_DISK_SPACE_USAGE_PERCENT:
+      /* This property can take values (-1, 0..100), where -1 indicates no value. */
+      g_value_init (value, G_TYPE_INT);
+      g_value_set_int (value, -1);
+      if ((shortcut->group & THUNAR_SHORTCUT_GROUP_DEVICES) != 0)
+        {
+          file = thunar_shortcut_get_file (shortcut);
+          if (file != NULL)
+            {
+              /* If the file system size is 0, assume that it could not be retrieved. */
+              if (thunar_g_file_get_free_space (file, &fs_free, &fs_size) && fs_size > 0)
+                g_value_set_int (value, (gint) ((gdouble) (fs_size - fs_free) / ((gdouble) fs_size / 100.0)));
+
+              g_object_unref (file);
+            }
+        }
+      break;
+
     default:
       _thunar_assert_not_reached ();
     }
@@ -1548,13 +1572,42 @@ thunar_shortcuts_model_save_bookmarks (ThunarShortcutsModel *model)
 
 
 
+static void
+thunar_shortcuts_model_device_added_finish (GFile      *location,
+                                            ThunarFile *file,
+                                            GError     *error,
+                                            gpointer    user_data)
+{
+  ThunarShortcutFileGetData *data = user_data;
+  ThunarShortcut            *shortcut = data->shortcut;
+  ThunarShortcutsModel      *model = data->model;
+
+  if (error == NULL)
+    {
+      shortcut->file = g_object_ref (file);
+
+      /* insert in the model */
+      thunar_shortcuts_model_add_shortcut (model, shortcut);
+
+      if (data->update_visibility)
+        thunar_shortcuts_model_header_visibility (model);
+    }
+
+  g_object_unref (location);
+  g_object_unref (model);
+  g_slice_free (ThunarShortcutFileGetData, data);
+}
+
+
+
 static void
 thunar_shortcuts_model_device_added (ThunarDeviceMonitor  *device_monitor,
                                      ThunarDevice         *device,
                                      ThunarShortcutsModel *model)
 {
-  ThunarShortcut *shortcut;
-  GFile          *mount_point;
+  ThunarShortcut            *shortcut;
+  ThunarShortcutFileGetData *data;
+  GFile                     *mount_point;
 
   _thunar_return_if_fail (device_monitor == NULL || THUNAR_DEVICE_MONITOR (device_monitor));
   _thunar_return_if_fail (device_monitor == NULL || model->device_monitor == device_monitor);
@@ -1566,13 +1619,6 @@ thunar_shortcuts_model_device_added (ThunarDeviceMonitor  *device_monitor,
   shortcut->device = g_object_ref (device);
   shortcut->hidden = thunar_device_get_hidden (device);
 
-  mount_point = thunar_device_get_root (device);
-  if (mount_point != NULL)
-    {
-      shortcut->file = thunar_file_get (mount_point, NULL);
-      g_object_unref (mount_point);
-    }
-
   switch (thunar_device_get_kind (device))
     {
     case THUNAR_DEVICE_KIND_VOLUME:
@@ -1588,13 +1634,27 @@ thunar_shortcuts_model_device_added (ThunarDeviceMonitor  *device_monitor,
       break;
     }
 
-  /* insert in the model */
-  thunar_shortcuts_model_add_shortcut (model, shortcut);
-
   /* header visibility if call is from monitor */
-  if (device_monitor != NULL
-      && !shortcut->hidden)
-    thunar_shortcuts_model_header_visibility (model);
+  gboolean update_visibility = (device_monitor != NULL && !shortcut->hidden);
+
+  mount_point = thunar_device_get_root (device);
+  if (mount_point != NULL)
+    {
+      data = g_slice_new0 (ThunarShortcutFileGetData);
+      data->shortcut = shortcut;
+      data->model = g_object_ref (model);
+      data->update_visibility = update_visibility;
+
+      thunar_file_get_async (mount_point, NULL, &thunar_shortcuts_model_device_added_finish, data);
+    }
+  else /* some devices (e.g. usb flashdrives) do not have a mountpoint */
+    {
+      /* insert in the model */
+      thunar_shortcuts_model_add_shortcut (model, shortcut);
+
+      if (update_visibility)
+        thunar_shortcuts_model_header_visibility (model);
+    }
 }
 
 
@@ -1617,7 +1677,12 @@ thunar_shortcuts_model_device_removed (ThunarDeviceMonitor  *device_monitor,
       break;
 
   /* something is broken if we don't have a shortcut here */
-  _thunar_assert (lp != NULL);
+  if (lp == NULL)
+    {
+      g_warning ("No shortcut found for device '%s'", thunar_device_get_name (device));
+      return;
+    }
+
   _thunar_assert (THUNAR_SHORTCUT (lp->data)->device == device);
 
   /* drop the shortcut from the model */
@@ -1651,7 +1716,12 @@ thunar_shortcuts_model_device_changed (ThunarDeviceMonitor  *device_monitor,
       break;
 
   /* something is broken if we don't have a shortcut here */
-  _thunar_assert (lp != NULL);
+  if (lp == NULL)
+    {
+      g_warning ("No shortcut found for device '%s'", thunar_device_get_name (device));
+      return;
+    }
+
   _thunar_assert (THUNAR_SHORTCUT (lp->data)->device == device);
 
   if (G_LIKELY (lp != NULL))
@@ -1794,6 +1864,19 @@ thunar_shortcuts_model_file_changed (ThunarFile           *file,
 
 
 
+static GFile *
+thunar_shortcut_get_file (ThunarShortcut *shortcut)
+{
+  if (shortcut->device != NULL)
+    return thunar_device_get_root (shortcut->device);
+  else if (shortcut->file != NULL)
+    return g_object_ref (thunar_file_get_file (shortcut->file));
+
+  return NULL;
+}
+
+
+
 static void
 thunar_shortcut_free (ThunarShortcut       *shortcut,
                       ThunarShortcutsModel *model)
@@ -2415,3 +2498,22 @@ thunar_shortcuts_model_set_hidden (ThunarShortcutsModel *model,
   /* header visibility */
   thunar_shortcuts_model_header_visibility (model);
 }
+
+
+
+void
+thunar_shortcuts_model_reload (ThunarShortcutsModel *model)
+{
+  GList          *l;
+  ThunarShortcut *shortcut;
+
+  for (l = model->shortcuts; l != NULL; l = l->next)
+    {
+      shortcut = l->data;
+
+      if (shortcut->device != NULL)
+        thunar_device_reload_file (shortcut->device);
+    }
+
+  thunar_shortcuts_model_reload_bookmarks (model);
+}
