@@ -18,10 +18,6 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
-
 #include "thunarx/thunarx-private.h"
 #include "thunarx/thunarx-renamer.h"
 #include "thunarx/thunarx-visibility.h"
